@@ -9,4 +9,4 @@ foreign_option_6="dhcp-option DOMAIN-ROUTE example.uk.com"
 
 TEST_TITLE="DNS Dual Domain, Dual Search, Dual Route (with Order Check)"
 TEST_BUSCTL_CALLED=1
-TEST_BUSCTL_DOMAINS="5 example.co false example.org false example.co.uk false example.net true example.uk.com true"
+TEST_BUSCTL_DOMAINS="6 example.com false example.org false example.co.uk false example.co false example.net true example.uk.com true"
